@@ -28,5 +28,6 @@ from .queries import Query, where
 from .storages import Storage, JSONStorage
 from .database import TinyDB
 from .version import __version__
+from .table import BaseID, BaseDocument
 
-__all__ = ('TinyDB', 'Storage', 'JSONStorage', 'Query', 'where')
+__all__ = ('TinyDB', 'Storage', 'JSONStorage', 'Query', 'where', "BaseID", "BaseDocument")
